Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(45)

Unified Diff: third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h

Issue 2715663002: ServiceWorker: Factor out FetchEvent related logics from RespondWithObserver. (Closed)
Patch Set: ServiceWorker: Factor out FetchEvent related logics from RespondWithObserver. Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h
diff --git a/third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h b/third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h
index aa5a0eba0cd2ea48518a354137d64d1c9395276d..2137783cd7501d510d48ae50c40880436355f957 100644
--- a/third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h
+++ b/third_party/WebKit/Source/modules/serviceworkers/FetchEvent.h
@@ -12,23 +12,22 @@
#include "modules/fetch/Request.h"
#include "modules/serviceworkers/ExtendableEvent.h"
#include "modules/serviceworkers/FetchEventInit.h"
-#include "modules/serviceworkers/RespondWithObserver.h"
#include "modules/serviceworkers/WaitUntilObserver.h"
#include "platform/heap/Handle.h"
namespace blink {
class ExceptionState;
+class FetchRespondWithObserver;
class Request;
class Response;
-class RespondWithObserver;
class ScriptState;
class WebDataConsumerHandle;
struct WebServiceWorkerError;
class WebURLResponse;
// A fetch event is dispatched by the client to a service worker's script
// context. RespondWithObserver can be used to notify the client about the
// service worker's response.
class MODULES_EXPORT FetchEvent final : public ExtendableEvent {
DEFINE_WRAPPERTYPEINFO();
@@ -43,7 +42,7 @@ class MODULES_EXPORT FetchEvent final : public ExtendableEvent {
static FetchEvent* create(ScriptState*,
const AtomicString& type,
const FetchEventInit&,
- RespondWithObserver*,
+ FetchRespondWithObserver*,
WaitUntilObserver*,
bool navigationPreloadSent);
@@ -68,12 +67,12 @@ class MODULES_EXPORT FetchEvent final : public ExtendableEvent {
FetchEvent(ScriptState*,
const AtomicString& type,
const FetchEventInit&,
- RespondWithObserver*,
+ FetchRespondWithObserver*,
WaitUntilObserver*,
bool navigationPreloadSent);
private:
- Member<RespondWithObserver> m_observer;
+ Member<FetchRespondWithObserver> m_observer;
Member<Request> m_request;
Member<PreloadResponseProperty> m_preloadResponseProperty;
String m_clientId;
@@ -12,23 +12,22 @@
class WebURLResponse;
// A fetch event is dispatched by the client to a service worker's script
-// context. RespondWithObserver can be used to notify the client about the
+// context. FetchRespondWithObserver can be used to notify the client about the
// service worker's response.
class MODULES_EXPORT FetchEvent final : public ExtendableEvent {

Powered by Google App Engine
This is Rietveld 408576698